@@ -352,7 +352,7 @@ static void _xfdashboard_applications_view_on_model_loaded(XfdashboardApplicatio
 /* The application will be resumed */
 static void _xfdashboard_applications_view_on_application_resume(XfdashboardApplicationsView *self, gpointer inUserData)
 {
-	XfdashboardApplicationsViewPrivate	*priv=self->priv;
+	XfdashboardApplicationsViewPrivate	*priv;
 
 	g_return_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(self));
 	g_return_if_fail(XFDASHBOARD_IS_APPLICATION(inUserData));
@@ -667,8 +667,8 @@ static gboolean _xfdashboard_applications_view_focusable_handle_key_event_at_lis
 	return(CLUTTER_EVENT_STOP);
 }
 
-static gboolean _xfdashboard_applications_view_focusable_handle_keypress_event(XfdashboardFocusable *inFocusable,
-																				const ClutterEvent *inEvent)
+static gboolean _xfdashboard_applications_view_focusable_handle_key_event(XfdashboardFocusable *inFocusable,
+																			const ClutterEvent *inEvent)
 {
 	XfdashboardApplicationsView				*self;
 	XfdashboardApplicationsViewPrivate		*priv;
@@ -680,52 +680,40 @@ static gboolean _xfdashboard_applications_view_focusable_handle_keypress_event(X
 	self=XFDASHBOARD_APPLICATIONS_VIEW(inFocusable);
 	priv=self->priv;
 
-	/* Move selection if an arrow key was pressed */
-	if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST)
+	/* Handle key events when key was released */
+	if(clutter_event_type(inEvent)==CLUTTER_KEY_RELEASE)
 	{
-		handledEvent=_xfdashboard_applications_view_focusable_handle_key_event_at_list_mode(self, inEvent);
-	}
-		else
+		/* Start selected application on ENTER */
+		switch(inEvent->key.keyval)
 		{
-			handledEvent=_xfdashboard_applications_view_focusable_handle_key_event_at_icon_mode(self, inEvent);
+			case CLUTTER_KEY_Return:
+			case CLUTTER_KEY_KP_Enter:
+			case CLUTTER_KEY_ISO_Enter:
+				if(priv->selectedItem)
+				{
+					if(XFDASHBOARD_IS_APPLICATION_BUTTON(priv->selectedItem))
+					{
+						_xfdashboard_applications_view_on_item_clicked(self, XFDASHBOARD_APPLICATION_BUTTON(priv->selectedItem));
+					}
+						else if(XFDASHBOARD_IS_BUTTON(priv->selectedItem))
+						{
+							_xfdashboard_applications_view_on_parent_menu_clicked(self, XFDASHBOARD_BUTTON(priv->selectedItem));
+						}
+				}
+				return(CLUTTER_EVENT_STOP);
 		}
 
-	if(handledEvent==CLUTTER_EVENT_STOP) return(handledEvent);
-
-	/* We did not handle this event */
-	return(CLUTTER_EVENT_PROPAGATE);
-}
-
-static gboolean _xfdashboard_applications_view_focusable_handle_keyrelease_event(XfdashboardFocusable *inFocusable,
-																					const ClutterEvent *inEvent)
-{
-	XfdashboardApplicationsView				*self;
-	XfdashboardApplicationsViewPrivate		*priv;
-
-	g_return_val_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable), CLUTTER_EVENT_PROPAGATE);
-	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(inFocusable), CLUTTER_EVENT_PROPAGATE);
-
-	self=XFDASHBOARD_APPLICATIONS_VIEW(inFocusable);
-	priv=self->priv;
-
-	/* Start selected application on ENTER */
-	switch(inEvent->key.keyval)
-	{
-		case CLUTTER_KEY_Return:
-		case CLUTTER_KEY_KP_Enter:
-		case CLUTTER_KEY_ISO_Enter:
-			if(priv->selectedItem)
+		/* Move selection if an arrow key was pressed */
+		if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST)
+		{
+			handledEvent=_xfdashboard_applications_view_focusable_handle_key_event_at_list_mode(self, inEvent);
+		}
+			else
 			{
-				if(XFDASHBOARD_IS_APPLICATION_BUTTON(priv->selectedItem))
-				{
-					_xfdashboard_applications_view_on_item_clicked(self, XFDASHBOARD_APPLICATION_BUTTON(priv->selectedItem));
-				}
-					else if(XFDASHBOARD_IS_BUTTON(priv->selectedItem))
-					{
-						_xfdashboard_applications_view_on_parent_menu_clicked(self, XFDASHBOARD_BUTTON(priv->selectedItem));
-					}
+				handledEvent=_xfdashboard_applications_view_focusable_handle_key_event_at_icon_mode(self, inEvent);
 			}
-			return(CLUTTER_EVENT_STOP);
+
+		if(handledEvent==CLUTTER_EVENT_STOP) return(handledEvent);
 	}
 
 	/* We did not handle this event */
@@ -740,8 +728,7 @@ void _xfdashboard_applications_view_focusable_iface_init(XfdashboardFocusableInt
 	iface->can_focus=_xfdashboard_applications_view_focusable_can_focus;
 	iface->set_focus=_xfdashboard_applications_view_focusable_set_focus;
 	iface->unset_focus=_xfdashboard_applications_view_focusable_unset_focus;
-	iface->handle_keypress_event=_xfdashboard_applications_view_focusable_handle_keypress_event;
-	iface->handle_keyrelease_event=_xfdashboard_applications_view_focusable_handle_keyrelease_event;
+	iface->handle_key_event=_xfdashboard_applications_view_focusable_handle_key_event;
 }
 
 /* IMPLEMENTATION: GObject */
