@@ -31,10 +31,18 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "theme.h" */
+GType xfdashboard_theme_error_enum_get_type(void) G_GNUC_CONST;
+#define XFDASHBOARD_TYPE_THEME_ERROR_ENUM	(xfdashboard_theme_error_enum_get_type())
+
 /* enumerations from "theme-css.h" */
 GType xfdashboard_theme_css_error_enum_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_THEME_CSS_ERROR_ENUM	(xfdashboard_theme_css_error_enum_get_type())
 
+/* enumerations from "theme-layout.h" */
+GType xfdashboard_theme_layout_error_enum_get_type(void) G_GNUC_CONST;
+#define XFDASHBOARD_TYPE_THEME_LAYOUT_ERROR_ENUM	(xfdashboard_theme_layout_error_enum_get_type())
+
 /* enumerations from "types.h" */
 GType xfdashboard_view_mode_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_VIEW_MODE	(xfdashboard_view_mode_get_type())
@@ -48,6 +56,8 @@ GType xfdashboard_background_type_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_BACKGROUND_TYPE	(xfdashboard_background_type_get_type())
 GType xfdashboard_corners_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_CORNERS	(xfdashboard_corners_get_type())
+GType xfdashboard_borders_get_type(void) G_GNUC_CONST;
+#define XFDASHBOARD_TYPE_BORDERS	(xfdashboard_borders_get_type())
 GType xfdashboard_fit_mode_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_FIT_MODE	(xfdashboard_fit_mode_get_type())
 G_END_DECLS
