@@ -33,10 +33,6 @@
 #include "marshal.h"
 #include "stylable.h"
 
-// TODO: #undef g_debug
-// TODO: #define g_debug g_message
-// TODO: #include "utils.h"
-
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardFocusManager,
 				xfdashboard_focus_manager,
@@ -580,29 +576,7 @@ gboolean xfdashboard_focus_manager_handle_key_event(XfdashboardFocusManager *sel
 	/* Synthesize event for current focused focusable actor */
 	if(priv->currentFocus)
 	{
-		gboolean					handled;
-
-		handled=CLUTTER_EVENT_PROPAGATE;
-
-		/* Try handler function depending on key event type */
-		switch(clutter_event_type(inEvent))
-		{
-			case CLUTTER_KEY_PRESS:
-				handled=xfdashboard_focusable_handle_keypress_event(priv->currentFocus, inEvent);
-				break;
-
-			case CLUTTER_KEY_RELEASE:
-				handled=xfdashboard_focusable_handle_keyrelease_event(priv->currentFocus, inEvent);
-				break;
-
-			default:
-				/* We should never get here */
-				g_assert_not_reached();
-				break;
-		}
-
-		/* Return handling result */
-		return(handled);
+		return(xfdashboard_focusable_handle_key_event(priv->currentFocus, inEvent));
 	}
 
 	/* If we get here there is no focus set */
