@@ -505,7 +505,6 @@ static void _xfdashboard_image_content_load_from_icon_name(XfdashboardImageConte
 	g_return_if_fail(XFDASHBOARD_IS_IMAGE_CONTENT(self));
 
 	priv=self->priv;
-	iconInfo=NULL;
 
 	/* Check if type of image is valid and all needed parameters are set */
 	g_return_if_fail(priv->type==XFDASHBOARD_IMAGE_TYPE_ICON_NAME);
@@ -662,13 +661,10 @@ static void _xfdashboard_image_content_load_from_icon_name(XfdashboardImageConte
 			 * the callback function we take an extra reference on this
 			 * instance. It will be release in callback function.
 			 */
-			gdk_pixbuf_new_from_stream_at_scale_async(stream,
-														priv->iconSize,
-														priv->iconSize,
-														TRUE,
-														NULL,
-														(GAsyncReadyCallback)_xfdashboard_image_content_loading_async_callback,
-														g_object_ref(self));
+			gdk_pixbuf_new_from_stream_async(stream,
+												NULL,
+												(GAsyncReadyCallback)_xfdashboard_image_content_loading_async_callback,
+												g_object_ref(self));
 
 			/* Release allocated resources */
 			g_object_unref(stream);
@@ -691,7 +687,6 @@ static void _xfdashboard_image_content_load_from_gicon(XfdashboardImageContent *
 	g_return_if_fail(XFDASHBOARD_IS_IMAGE_CONTENT(self));
 
 	priv=self->priv;
-	iconInfo=NULL;
 
 	/* Check if type of image is valid and all needed parameters are set */
 	g_return_if_fail(priv->type==XFDASHBOARD_IMAGE_TYPE_GICON);
@@ -1222,7 +1217,6 @@ ClutterImage* xfdashboard_image_content_new_for_pixbuf(GdkPixbuf *inPixbuf)
 
 	g_return_val_if_fail(GDK_IS_PIXBUF(inPixbuf), NULL);
 
-	image=NULL;
 	error=NULL;
 
 	/* Create ClutterImage for pixbuf directly because images
