@@ -754,8 +754,8 @@ static void _xfdashboard_search_view_focusable_unset_focus(XfdashboardFocusable
 }
 
 /* Virtual function "handle_key_event" was called */
-static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(XfdashboardFocusable *inFocusable,
-																			const ClutterEvent *inEvent)
+static gboolean _xfdashboard_search_view_focusable_handle_key_event(XfdashboardFocusable *inFocusable,
+																	const ClutterEvent *inEvent)
 {
 	XfdashboardSearchView			*self;
 	XfdashboardSearchViewPrivate	*priv;
@@ -770,12 +770,38 @@ static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(Xfdashb
 
 	/* Handle key events at container of selected provider */
 	if(priv->selectionProvider &&
-		priv->selectionProvider->container)
+		priv->selectionProvider->container &&
+		clutter_event_type(inEvent)==CLUTTER_KEY_RELEASE)
 	{
+		ClutterActor				*currentSelection;
 		ClutterActor				*newSelection;
 		gboolean					doGetPrevious;
 		gint						selectionDirection;
 
+		/* Emit click on current selection when ENTER was pressed */
+		switch(inEvent->key.keyval)
+		{
+			case CLUTTER_KEY_Return:
+			case CLUTTER_KEY_KP_Enter:
+			case CLUTTER_KEY_ISO_Enter:
+				/* Get current selection to lookup mapping */
+				currentSelection=xfdashboard_search_result_container_get_current_selection(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container));
+				if(currentSelection)
+				{
+					XfdashboardSearchViewProviderItemsMapping	*mapping;
+
+					/* Get mapping of current selection to determine actor where to emit click action */
+					mapping=_xfdashboard_search_view_provider_data_get_mapping_by_actor(priv->selectionProvider, currentSelection);
+					if(mapping)
+					{
+						_xfdashboard_search_view_on_provider_item_actor_clicked(XFDASHBOARD_CLICK_ACTION(mapping->clickAction),
+																				mapping->actor,
+																				mapping);
+					}
+				}
+				return(CLUTTER_EVENT_STOP);
+		}
+
 		/* Move selection if an corresponding key was pressed */
 		switch(inEvent->key.keyval)
 		{
@@ -809,6 +835,9 @@ static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(Xfdashb
 
 		if(handledEvent==CLUTTER_EVENT_STOP)
 		{
+			/* Get current selection to determine if selection has changed */
+			currentSelection=xfdashboard_search_result_container_get_current_selection(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container));
+
 			/* Get new selection */
 			if(doGetPrevious)
 			{
@@ -839,8 +868,12 @@ static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(Xfdashb
 					/* Unset focus at current provider and set focus to new one if changed */
 					if(newSelectionProvider!=priv->selectionProvider)
 					{
-						xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
-																		FALSE);
+						if(priv->selectionProvider &&
+							priv->selectionProvider->container)
+						{
+							xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
+																			FALSE);
+						}
 
 						priv->selectionProvider=newSelectionProvider;
 						xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
@@ -853,7 +886,7 @@ static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(Xfdashb
 				}
 					else
 					{
-						/* Get previous provider to focus */
+						/* Get next provider to focus */
 						newSelectionProviderInList=g_list_next(newSelectionProviderInList);
 						if(!newSelectionProviderInList) newSelectionProviderInList=g_list_first(priv->providers);
 						newSelectionProvider=(XfdashboardSearchViewProviderData*)newSelectionProviderInList->data;
@@ -861,15 +894,19 @@ static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(Xfdashb
 						/* Unset focus at current provider and set focus to new one if changed */
 						if(newSelectionProvider!=priv->selectionProvider)
 						{
-							xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
-																			FALSE);
+							if(priv->selectionProvider &&
+								priv->selectionProvider->container)
+							{
+								xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
+																				FALSE);
+							}
 
 							priv->selectionProvider=newSelectionProvider;
 							xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
 																			TRUE);
 						}
 
-						/* Get last selectable item at newly selected provider */
+						/* Get first selectable item at newly selected provider */
 						newSelection=xfdashboard_search_result_container_set_next_selection(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
 																							XFDASHBOARD_SEARCH_RESULT_CONTAINER_SELECTION_STEP_SIZE_BEGIN_END);
 					}
@@ -887,56 +924,6 @@ static gboolean _xfdashboard_search_view_focusable_handle_keypress_event(Xfdashb
 	return(handledEvent);
 }
 
-/* Virtual function "handle_keyrelease_event" was called */
-static gboolean _xfdashboard_search_view_focusable_handle_keyrelease_event(XfdashboardFocusable *inFocusable,
-																			const ClutterEvent *inEvent)
-{
-	XfdashboardSearchView			*self;
-	XfdashboardSearchViewPrivate	*priv;
-	gboolean						handledEvent;
-
-	g_return_val_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable), CLUTTER_EVENT_PROPAGATE);
-	g_return_val_if_fail(XFDASHBOARD_IS_SEARCH_VIEW(inFocusable), CLUTTER_EVENT_PROPAGATE);
-
-	self=XFDASHBOARD_SEARCH_VIEW(inFocusable);
-	priv=self->priv;
-	handledEvent=CLUTTER_EVENT_PROPAGATE;
-
-	/* Handle key events at container of selected provider */
-	if(priv->selectionProvider &&
-		priv->selectionProvider->container)
-	{
-		ClutterActor				*currentSelection;
-
-		/* Emit click on current selection when ENTER was pressed */
-		switch(inEvent->key.keyval)
-		{
-			case CLUTTER_KEY_Return:
-			case CLUTTER_KEY_KP_Enter:
-			case CLUTTER_KEY_ISO_Enter:
-				/* Get current selection to lookup mapping */
-				currentSelection=xfdashboard_search_result_container_get_current_selection(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container));
-				if(currentSelection)
-				{
-					XfdashboardSearchViewProviderItemsMapping	*mapping;
-
-					/* Get mapping of current selection to determine actor where to emit click action */
-					mapping=_xfdashboard_search_view_provider_data_get_mapping_by_actor(priv->selectionProvider, currentSelection);
-					if(mapping)
-					{
-						_xfdashboard_search_view_on_provider_item_actor_clicked(XFDASHBOARD_CLICK_ACTION(mapping->clickAction),
-																				mapping->actor,
-																				mapping);
-					}
-				}
-				return(CLUTTER_EVENT_STOP);
-		}
-	}
-
-	/* Return result of key handling */
-	return(handledEvent);
-}
-
 /* Interface initialization
  * Set up default functions
  */
@@ -945,8 +932,7 @@ void _xfdashboard_search_view_focusable_iface_init(XfdashboardFocusableInterface
 	iface->can_focus=_xfdashboard_search_view_focusable_can_focus;
 	iface->set_focus=_xfdashboard_search_view_focusable_set_focus;
 	iface->unset_focus=_xfdashboard_search_view_focusable_unset_focus;
-	iface->handle_keypress_event=_xfdashboard_search_view_focusable_handle_keypress_event;
-	iface->handle_keyrelease_event=_xfdashboard_search_view_focusable_handle_keyrelease_event;
+	iface->handle_key_event=_xfdashboard_search_view_focusable_handle_key_event;
 }
 
 
@@ -1276,3 +1262,43 @@ void xfdashboard_search_view_update_search(XfdashboardSearchView *self, const gc
 	g_timer_destroy(timer);
 #endif
 }
+
+/* Reset selection to first item in current search result */
+void xfdashboard_search_view_reset_search_selection(XfdashboardSearchView *self)
+{
+	XfdashboardSearchViewPrivate		*priv;
+	XfdashboardSearchViewProviderData	*newSelectionProvider;
+	ClutterActor						*newSelection;
+
+	g_return_if_fail(XFDASHBOARD_IS_SEARCH_VIEW(self));
+
+	priv=self->priv;
+
+	/* Do nothing if no provider was registered */
+	if(!priv->providers) return;
+
+	/* Get first provider to focus */
+	newSelectionProvider=(XfdashboardSearchViewProviderData*)priv->providers->data;
+
+	/* Unset focus at current provider and set focus to new one if changed */
+	if(newSelectionProvider!=priv->selectionProvider)
+	{
+		if(priv->selectionProvider &&
+			priv->selectionProvider->container)
+		{
+			xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
+															FALSE);
+		}
+
+		priv->selectionProvider=newSelectionProvider;
+		xfdashboard_search_result_container_set_focus(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
+														TRUE);
+	}
+
+	/* Get frist selectable item at newly selected provider */
+	newSelection=xfdashboard_search_result_container_set_next_selection(XFDASHBOARD_SEARCH_RESULT_CONTAINER(priv->selectionProvider->container),
+																		XFDASHBOARD_SEARCH_RESULT_CONTAINER_SELECTION_STEP_SIZE_BEGIN_END);
+
+	/* Ensure new selection is visible */
+	xfdashboard_view_ensure_visible(XFDASHBOARD_VIEW(self), newSelection);
+}
