@@ -71,7 +71,8 @@ typedef enum /*< prefix=XFDASHBOARD_THEME_CSS_ERROR >*/
 {
 	XFDASHBOARD_THEME_CSS_ERROR_INVALID_ARGUMENT,
 	XFDASHBOARD_THEME_CSS_ERROR_UNSUPPORTED_STREAM,
-	XFDASHBOARD_THEME_CSS_ERROR_PARSER_ERROR
+	XFDASHBOARD_THEME_CSS_ERROR_PARSER_ERROR,
+	XFDASHBOARD_THEME_CSS_ERROR_FUNCTION_ERROR
 } XfdashboardThemeCSSErrorEnum;
 
 /* Public declarations */
